@@ -9,7 +9,7 @@ import (
 	"github.com/spf13/cobra"
 )
 
-// noticeCmd represents the get command
+// noticeCmd represents the notice command
 var noticeCmd = &cobra.Command{
 	Use:   "notice",
 	Short: "Print the upgrade notice when a new version is available.",
@@ -25,9 +25,7 @@ var noticeCmd = &cobra.Command{
 		defer env.Close()
 
 		sh := os.Getenv("POSH_SHELL")
-		configFile := config.Path(configFlag)
-		cfg, _ := config.Load(configFile, sh, false)
-		cfg.Upgrade.Cache = env.Cache()
+		cfg, _ := config.Load(configFlag, sh, false)
 
 		if notice, hasNotice := cfg.Upgrade.Notice(); hasNotice {
 			fmt.Println(notice)
