@@ -19,7 +19,7 @@ func Base(input string) string {
 		input = input[0 : len(input)-1]
 	}
 
-	if len(input) == 0 {
+	if input == "" {
 		return Separator()
 	}
 
@@ -40,7 +40,7 @@ func Base(input string) string {
 	}
 
 	// If empty now, it had only slashes.
-	if len(input) == 0 {
+	if input == "" {
 		return Separator()
 	}
 
@@ -48,7 +48,7 @@ func Base(input string) string {
 }
 
 func Clean(input string) string {
-	if len(input) == 0 {
+	if input == "" {
 		return input
 	}
 
@@ -68,7 +68,7 @@ func Clean(input string) string {
 		// Clean the prefix for a UNC path, if any.
 		if regex.MatchString(`^\\{2}[^\\]+`, cleaned) {
 			cleaned = strings.TrimPrefix(cleaned, `\\.\UNC\`)
-			if len(cleaned) == 0 {
+			if cleaned == "" {
 				return cleaned
 			}
 			prefix = `\\`
@@ -104,7 +104,7 @@ func ReplaceHomeDirPrefixWithTilde(path string) string {
 	}
 
 	rem := path[len(home):]
-	if len(rem) == 0 || IsSeparator(rem[0]) {
+	if rem == "" || IsSeparator(rem[0]) {
 		return "~" + rem
 	}
 
@@ -117,7 +117,7 @@ func ReplaceTildePrefixWithHomeDir(path string) string {
 	}
 
 	rem := path[1:]
-	if len(rem) == 0 || IsSeparator(rem[0]) {
+	if rem == "" || IsSeparator(rem[0]) {
 		return Home() + rem
 	}
 
