@@ -103,7 +103,7 @@ func (hg *Mercurial) setMercurialStatus() {
 	hg.Branch = hg.command
 
 	idString := hg.getHgCommandOutput("log", "-r", ".", "--template", hgLogTemplate)
-	if len(idString) == 0 {
+	if idString == "" {
 		return
 	}
 
@@ -139,7 +139,7 @@ func (hg *Mercurial) setMercurialStatus() {
 
 	statusString := hg.getHgCommandOutput("status")
 
-	if len(statusString) == 0 {
+	if statusString == "" {
 		return
 	}
 
@@ -151,7 +151,7 @@ func (hg *Mercurial) setMercurialStatus() {
 }
 
 func doSplit(s string) []string {
-	if len(s) == 0 {
+	if s == "" {
 		return []string{}
 	}
 
