@@ -22,7 +22,7 @@ func (f Feature) Cmd() Code {
 		return `os.execute(string.format('"%s" upgrade', omp_executable))`
 	case Notice:
 		return `os.execute(string.format('"%s" notice', omp_executable))`
-	case PromptMark, PoshGit, Azure, LineError, Jobs, CursorPositioning:
+	case PromptMark, PoshGit, Azure, LineError, Jobs, CursorPositioning, Async:
 		fallthrough
 	default:
 		return ""
@@ -30,7 +30,7 @@ func (f Feature) Cmd() Code {
 }
 
 func escapeLuaStr(str string) string {
-	if len(str) == 0 {
+	if str == "" {
 		return str
 	}
 	// We only replace a minimal set of special characters with corresponding escape sequences, without adding surrounding quotes.
