@@ -23,7 +23,7 @@ func (f Feature) Fish() Code {
 		return unixUpgrade
 	case Notice:
 		return unixNotice
-	case RPrompt, PoshGit, Azure, LineError, Jobs, CursorPositioning:
+	case RPrompt, PoshGit, Azure, LineError, Jobs, CursorPositioning, Async:
 		fallthrough
 	default:
 		return ""
@@ -31,7 +31,7 @@ func (f Feature) Fish() Code {
 }
 
 func quoteFishStr(str string) string {
-	if len(str) == 0 {
+	if str == "" {
 		return "''"
 	}
 
