@@ -89,6 +89,7 @@ const (
 	empty = "<>"
 
 	startProgress = "\x1b]9;4;3;0\x07"
+	setProgress   = "\x1b]9;4;4;%d\x07"
 	endProgress   = "\x1b]9;4;0;0\x07"
 
 	WindowsTerminal = "Windows Terminal"
@@ -185,7 +186,7 @@ func ClearAfter() string {
 func FormatTitle(title string) string {
 	switch Shell {
 	// These shells don't support setting the console title.
-	case shell.ELVISH, shell.XONSH, shell.TCSH:
+	case shell.ELVISH, shell.XONSH:
 		return ""
 	case shell.BASH, shell.ZSH:
 		title = trimAnsi(title)
@@ -252,6 +253,14 @@ func StartProgress() string {
 	return startProgress
 }
 
+func SetProgress(percentage int) string {
+	if Program != WindowsTerminal {
+		return ""
+	}
+
+	return fmt.Sprintf(setProgress, percentage)
+}
+
 func StopProgress() string {
 	if Program != WindowsTerminal {
 		return ""
@@ -261,7 +270,7 @@ func StopProgress() string {
 }
 
 func Write(background, foreground color.Ansi, text string) {
-	if len(text) == 0 {
+	if text == "" {
 		return
 	}
 
@@ -595,11 +604,11 @@ func endColorOverride(position int) int {
 }
 
 func asAnsiColors(background, foreground color.Ansi) (color.Ansi, color.Ansi) {
-	if len(background) == 0 {
+	if background == "" {
 		background = color.Background
 	}
 
-	if len(foreground) == 0 {
+	if foreground == "" {
 		foreground = color.Foreground
 	}
 
@@ -623,7 +632,7 @@ func asAnsiColors(background, foreground color.Ansi) (color.Ansi, color.Ansi) {
 }
 
 func trimAnsi(text string) string {
-	if len(text) == 0 || !strings.Contains(text, "\x1b") {
+	if text == "" || !strings.Contains(text, "\x1b") {
 		return text
 	}
 	return regex.ReplaceAllString(AnsiRegex, text, "")
